<?php
/**
 * @brief		Editor Extension: memberAway
 * @author		<a href='https://www.invisioncommunity.com'>Invision Power Services, Inc.</a>
 * @copyright	(c) Invision Power Services, Inc.
 * @license		https://www.invisioncommunity.com/legal/standards/
 * @package		Invision Community
 * @subpackage	Member Away
 * @since		11 Aug 2019
 */

namespace IPS\memberaway\extensions\core\EditorLocations;

/* To prevent PHP errors (extending class does not exist) revealing path */
if ( !\defined( '\IPS\SUITE_UNIQUE_KEY' ) )
{
	header( ( isset( $_SERVER['SERVER_PROTOCOL'] ) ? $_SERVER['SERVER_PROTOCOL'] : 'HTTP/1.0' ) . ' 403 Forbidden' );
	exit;
}

/**
 * Editor Extension: memberAway
 */
class _memberAway
{
	public function canUseHtml( $member )
	{
		return NULL;
	}

	public function canAttach( $member, $field )
	{
		return FALSE;
	}

	public function attachmentPermissionCheck( $member, $id1, $id2, $id3, $attachment )
	{
		return FALSE;
	}

	public function attachmentLookup( $id1, $id2, $id3 )
	{
		return FALSE;
	}

	public function rebuildAttachmentImages( $offset, $max )
	{
		return $this->performRebuild( $offset, $max, array( 'IPS\Text\Parser', 'rebuildAttachmentUrls' ) );
	}

	public function rebuildContent( $offset, $max )
	{
		return $this->performRebuild( $offset, $max, array( 'IPS\Text\LegacyParser', 'parseStatic' ) );
	}

	protected $proxyUrl	= FALSE;

	public function rebuildImageProxy( $offset, $max, $proxyUrl = FALSE )
	{
		$this->proxyUrl = $proxyUrl;
		return $this->performRebuild( $offset, $max, 'parseImageProxy' );
	}

	protected $_lazyLoadStatus = null;

	public function rebuildLazyLoad( $offset, $max, $status=TRUE )
	{
		$this->_lazyLoadStatus = $status;

		return $this->performRebuild( $offset, $max, 'parseLazyLoad' );
	}

	protected function performRebuild( $offset, $max, $callback )
	{
		$did = 0;

		foreach( \IPS\Db::i()->select( '*', 'memberaway_data', null, 'ma_mid ASC', array( $offset, $max ) ) as $note )
		{
			$did++;
			try
			{
				if( $callback == 'parseImageProxy' )
				{
					$rebuilt = \IPS\Text\Parser::removeImageProxy( $note['ma_text'] );
				}
				elseif( $callback == 'parseLazyLoad' )
				{
					$rebuilt = \IPS\Text\Parser::parseLazyLoad( $note['ma_text'], $this->_lazyLoadStatus );
				}
				else
				{
					$rebuilt = $callback( $note['ma_text'] );
				}
				
			}
			catch( \InvalidArgumentException $e )
			{
				if( $callback[1] == 'parseStatic' AND $e->getcode() == 103014 )
				{
					$rebuilt = preg_replace( "#\[/?([^\]]+?)\]#", '', $note['ma_text'] );
				}
				else
				{
					throw $e;
				}
			}

			if( $rebuilt !== FALSE )
			{
				\IPS\Db::i()->update( 'memberaway_data', array( 'ma_text' => $rebuilt ), array( 'ma_mid=?', $note['ma_mid'] ) );
			}
		}

		return $did;
	}

	public function contentCount()
	{
		return \IPS\Db::i()->select( 'COUNT(*) as count', 'memberaway_data', "ma_text IS NOT NULL" )->first();
	}
}