<?php

namespace IPS\memberaway\extensions\core\Queue;

/* To prevent PHP errors (extending class does not exist) revealing path */
if ( !\defined( '\IPS\SUITE_UNIQUE_KEY' ) )
{
	header( ( isset( $_SERVER['SERVER_PROTOCOL'] ) ? $_SERVER['SERVER_PROTOCOL'] : 'HTTP/1.0' ) . ' 403 Forbidden' );
	exit;
}

class _Away
{
	public $rebuild	= \IPS\REBUILD_NORMAL;

	public function preQueueData( $data )
	{
		try
		{
			$data['count'] = (int) \IPS\Db::i()->select( 'COUNT(*)', 'core_members', array( 'membersaway_on=?', 1 ) )->first();
		}
		catch( \Exception $ex )
		{
			throw new \OutOfRangeException;
		}
		
		if( $data['count'] == 0 )
		{
			return null;
		}

		return $data;
	}

	public function run( $data, $offset )
	{
		$select = \IPS\Db::i()->select( 'member_id, membersaway_on, membersaway_text, membersaway_date', 'core_members', array( 'membersaway_on=?', 1 ), 'member_id ASC', array( $offset, $this->rebuild ) );

		if( !$select->count() )
		{
			throw new \IPS\Task\Queue\OutOfRangeException;
		}

		foreach( $select as $row )
		{
			$status  = new \IPS\memberaway\Status;

			$status->mid  = $row['member_id'];
			$status->on   = $row['membersaway_on'];
			$status->text = $row['membersaway_text'];
			$status->date = $row['membersaway_date'];

			$status->save();
		}

		return $offset + $this->rebuild;
	}

	public function getProgress( $data, $offset )
	{
		return array( 'text' => \IPS\Member::loggedIn()->language()->addToStack( 'ma_rebuilding_members_data' ), 'complete' => $data['count'] ? ( round( 100 / $data['count'] * $offset, 2 ) ) : 100 );
	}

	public function postComplete( $data )
	{
		try
		{
			$pluginData = \IPS\Db::i()->select( '*', 'core_plugins', array( 'plugin_location=?', "memberaway" ) )->first();
			try
			{
				$plugin = \IPS\Plugin::load( $pluginData['plugin_id'] );
				$plugin->delete();
			}
			catch ( \Exception $e ){}
		}
		catch( \UnderflowException $e ){}
	}
}