<?php

namespace IPS\memberaway\modules\admin\memberaway;

/* To prevent PHP errors (extending class does not exist) revealing path */
if ( !\defined( '\IPS\SUITE_UNIQUE_KEY' ) )
{
	header( ( isset( $_SERVER['SERVER_PROTOCOL'] ) ? $_SERVER['SERVER_PROTOCOL'] : 'HTTP/1.0' ) . ' 403 Forbidden' );
	exit;
}

/**
 * members
 */
class _members extends \IPS\Dispatcher\Controller
{
	/**
	 * @brief	Has been CSRF-protected
	 */
	public static $csrfProtected = TRUE;

	/**
	 * Manage
	 *
	 * @return	void
	 */
	protected function manage()
	{		
		\IPS\Dispatcher::i()->checkAcpPermission( 'members_manage' );

		$table = new \IPS\Helpers\Table\Db( 'memberaway_data', \IPS\Http\Url::internal( 'app=memberaway&module=memberaway&controller=members' ), array( array( 'ma_on=1' ) ) );
		$table->include = array( 'ma_mid', 'ma_text', 'ma_days', 'ma_date' );
		//$table->widths = array( 'ma_mid' => 15, 'ma_text' => 60, 'ma_days' => 15, 'ma_date' => 10 );
		$table->widths['ma_text'] = '60';
		$table->noSort	= array( 'ma_mid', 'ma_text' );

		$table->parsers = array(
			'ma_mid'	=> function( $val, $row )
			{
				$member = \IPS\Member::load( $val );
				if ( $member->member_id )
				{
					return \IPS\Theme::i()->getTemplate( 'global', 'core' )->userPhoto( $member, 'tiny' ) . \IPS\Theme::i()->getTemplate( 'global', 'core' )->userLink( $member, 'tiny' );
				}
				else
				{
					return \IPS\Member::loggedIn()->language()->addToStack('deleted_member');
				}
			},
			'ma_text'	=> function( $val, $row )
			{
				return \IPS\Theme::i()->getTemplate( 'global', 'core', 'global' )->richText( $val, array( 'ipsType_break ipsContained' ) );
			},
			'ma_days'	=> function( $val, $row )
			{
				return $val . ' ' . \IPS\Member::loggedIn()->language()->addToStack( 'days' );
			},
			'ma_date'	=> function( $val, $row )
			{
				return \IPS\DateTime::ts( $val )->localeDate();
			},
		);

		\IPS\Output::i()->sidebar['actions']['toggleall'] = array(
			'primary'	=> true,
			'icon'		=> 'toggle-on',
			'title'		=> 'membersaway_removeStatus_all',
			'link'		=> \IPS\Http\Url::internal( 'app=memberaway&module=memberaway&controller=members&do=toggleAll' )->csrf(),
			'data'	=> array( 'confirm' => '', 'confirmSubMessage' => \IPS\Member::loggedIn()->language()->addToStack('membersaway_removeStatus_all_desc' ) )
		);

		$table->rowButtons = function( $row )
		{
			$return = array(
				'toggle'	=> array(
					'icon'	=> 'toggle-on',
					'title'	=> 'membersaway_removeStatus',
					'link'	=> \IPS\Http\Url::internal( 'app=memberaway&module=memberaway&controller=members&do=toggle' )->setQueryString( 'mid', $row['ma_mid'] )->csrf(),
					'data'	=> array( 'confirm' => '', 'confirmSubMessage' => \IPS\Member::loggedIn()->language()->addToStack('membersaway_removeStatus_desc' ) )
				)
			);

			return $return;
		};

		$table->limit = 10;
		$table->sortBy = $table->sortBy ?: 'ma_date';
		$table->sortDirection = $table->sortDirection ?: 'desc';

		\IPS\Output::i()->title		= \IPS\Member::loggedIn()->language()->addToStack('menu__memberaway_memberaway_members');
		\IPS\Output::i()->output = (string) $table;
	}

	protected function toggleAll()
	{
		\IPS\Request::i()->confirmedDelete();
		\IPS\Session::i()->csrfCheck();

		\IPS\Db::i()->delete( 'memberaway_data' );

		\IPS\Session::i()->log( 'memberaway_removed_status_all' );
		\IPS\Output::i()->redirect( \IPS\Http\Url::internal( 'app=memberaway&module=memberaway&controller=members' ), 'completed' );
	}

	protected function toggle()
	{
		\IPS\Request::i()->confirmedDelete();
		\IPS\Session::i()->csrfCheck();

		\IPS\Db::i()->delete( 'memberaway_data', array( 'ma_mid=?', \IPS\Request::i()->mid ) );

		$member = \IPS\Member::load( \IPS\Request::i()->mid );
		$log = \IPS\Member::loggedIn()->language()->addToStack('away_status_toggled_from', FALSE, array( 'sprintf' => $member->name ) );
		\IPS\Member::loggedIn()->language()->parseOutputForDisplay( $log );
		\IPS\Session::i()->log( $log );

		\IPS\Output::i()->redirect( \IPS\Http\Url::internal( 'app=memberaway&module=memberaway&controller=members' ), 'completed' );
	}
}